@@ -2,7 +2,7 @@ package Devel::Examine::Subs;
 use warnings;
 use strict;
 
-our $VERSION = '1.29';
+our $VERSION = '1.30';
 
 use Carp;
 use Data::Compare;
@@ -148,7 +148,6 @@ sub _params {
 }
 sub _config {
 
-
     my $self = shift;
     my $p = shift;
 
@@ -192,6 +191,7 @@ sub _config {
         config_dump => 0,
         cache_dump => 0,
         inject_use => 0,
+        inject_after_sub_def => 0,
         delete => 0,
     );
 
@@ -301,7 +301,8 @@ sub _file {
         my $module_is_loaded;
         
         if (! $INC{$file}){
-            eval { require $module; };
+            
+            eval { use Data::Dump; };
 
             if ($@){
                 $@ = "Devel::Examine::Subs::_file() speaking ... " .
@@ -809,9 +810,9 @@ sub inject {
     my $self = shift;
     my $p = $self->_params(@_);
 
-    # inject_use is a preproc
+    # inject_use/inject_after_sub_def are preprocs
 
-    if ($p->{inject_use}){
+    if ($p->{inject_use} || $p->{inject_after_sub_def}){
         $self->{params}{pre_proc} = 'inject';
         $self->{params}{pre_proc_return} = 1;
     }
@@ -1164,15 +1165,20 @@ with '.bak', but don't confuse this feature with the 'copy' parameter.
 
 =head2 C<inject>
 
-Parameters: C<inject_use =E<gt> ['use Module::Name', 'use Module2::Name']>
+Parameters: C<inject_use =E<gt> ['use Module::Name', 'use Module2::Name']> or
+C<inject_after_sub_def =E<gt> ['code line 1;', 'code line 2;']>
 
-The only current option is this parameter. It will inject the statements prior
-to all existing C<use> statements that already exist in the file(s). If none
-are found, will inject the statements right after a C<Package> statement if
-found.
+C<inject_use> will inject the statements prior to all existing C<use>
+statements that already exist in the file(s). If none are found, will inject
+the statements right after a C<Package> statement if found.
 
 Technically, you don't have to inject a C<use> statement, but I'd advise it.
 
+C<inject_after_sub_def> will inject the lines of code within the array
+reference value immediately following all sub definitions in a file.
+Next line indenting is used, and sub definitions with their opening brace
+on a separate line than the definition itself is caught.
+
 
 
 =head2 C<remove>
