@@ -10,7 +10,7 @@ use Devel::Examine::Subs::Sub;
 use File::Copy;
 use Tie::File;
 
-our $VERSION = '1.29';
+our $VERSION = '1.30';
 
 sub new {
 
@@ -308,8 +308,9 @@ sub inject_after {
         my $num_injects = $p->{injects} // 1;
         my $code = $p->{code};
         my $copy = $p->{copy};
+        my $sub_def = $p->{sub_def};
 
-        if (! $search){
+        if (! $sub_def && ! $search){
             croak "\nDevel::Examine::Subs::Engine::inject_after speaking:\n" .
                     "can't use inject_after engine without specifying a " .
                     "search term\n\n";
@@ -363,7 +364,6 @@ sub inject_after {
             
                 tie my @tie_file, 'Tie::File', $file;
 
-
                 my $line_num = 0;
                 my $new_lines = 0; # don't search added lines
 
@@ -393,7 +393,6 @@ sub inject_after {
                             $new_lines++;
                             $end_line++;
                         }
-                        splice @tie_file, $location++, 0, '';
 
                         # stop injecting after N search finds
 
