@@ -6,7 +6,7 @@ use warnings;
 use Carp;
 use Data::Dumper;
 
-our $VERSION = '1.29';
+our $VERSION = '1.30';
 
 sub new {
 
@@ -84,16 +84,20 @@ sub inject {
         my $p = shift;
         my $file = $p->{file};
 
+        tie my @file, 'Tie::File', $file or die $!;
+
         if ($p->{inject_use}) {
-            
-            tie my @file, 'Tie::File', $file or die $!;
 
             my $use = qr/use\s+\w+/;
 
-            my ($index) = grep { $file[$_] =~ $use } 0..$#file;
+            my ($index) = grep {
+                $file[$_] =~ $use
+            } 0..$#file;
 
-            if (! $index) {
-                ($index) = grep { $file[$_] =~ /^package\s+\w+/ } 0..$#file;
+            if (!$index) {
+                ($index) = grep {
+                    $file[$_] =~ /^package\s+\w+/
+                } 0..$#file;
             }
 
             if ($index) {
@@ -106,6 +110,58 @@ sub inject {
 
             return;
         }
+
+        if ($p->{inject_after_sub_def}) {
+
+            my $code = $p->{inject_after_sub_def};
+
+            my @new_file;
+
+            my $single_line = qr/
+                sub\s+\w+\s*(?:\(.*?\)\s+)?\{\s*(?!\s*[\S])
+                |
+                sub\s+\{\s*(?!\s*[\S])
+                /x;
+
+            my $multi_line = qr/sub\s+\w+\s*(?![\S])/;
+
+            my $is_multi = 0;
+
+            while (my ($i, $e) = each @file){
+
+                my $indent = '';
+
+                my $count = $i;
+                $count++;
+
+                if ($file[$count] && $file[$count] =~ /^(\s+)/){
+                    $indent = $1;
+                }
+
+                push @new_file, $e;
+
+                if ($e =~ $single_line) {
+                    for (@$code){
+                        push @new_file, $indent . $_;
+                    }
+                }
+                elsif ($e =~ $multi_line) {
+                    if ($file[$count] =~ /\s*\{\s*(?!\s*[\S])/) {
+                        $is_multi = 1;
+                        next;
+                    }
+                }
+
+                if ($is_multi) {
+                    for (@$code) {
+                        push @new_file, $indent . $_;
+                    }
+                    $is_multi = 0;
+                }
+            }
+
+            @file = @new_file;
+        }
     }
 }
 
@@ -182,13 +238,28 @@ is valid.
 
 =head2 C<module>
 
-Mandatory parameters: C<{ module => 'Module::Name' }>
+Mandatory parameters: C<{ module =E<gt> 'Module::Name' }>
 
 This pre-processor returns an array reference of all subroutines within the
 namespace of the module listed in the C<module> parameter.
 
 The data is returned early as mentioned in the L<DESCRIPTION>.
 
+=head2 C<inject>
+
+Parameters: C<{ inject_use =E<gt> ['use statement1;', 'use statement2;'] }>
+or C<{ inject_after_sub_def =E<gt> ['code line 1;', 'code line 2;'] }>
+
+Injects each element of the array ref as either a use statement, or in the
+latter case, lines of code after a sub definition.
+
+=head2 C<remove>
+
+Parameters: C<delete =E<gt> 'string'>
+
+Deletes the entire line of code, if it contains 'string'.
+
+
 =head1 AUTHOR
 
 Steve Bertrand, C<< <steveb at cpan.org> >>
